@@ -27,7 +27,7 @@ typedef struct {
 	gchar *my_char;
 } Tconvert_table;
 
-typedef enum { 
+typedef enum {
 	tcc2i_full_match = 0,
 	tcc2i_firstchar,
 	tcc2i_mycharlen,
@@ -48,9 +48,7 @@ void refcpointer_ref(Trefcpointer *rp);
 #endif
 void refcpointer_unref(Trefcpointer *rp);
 
-GFile *add_suffix_to_uri(GFile *file, const char *suffix);
-const gchar *full_path_utf8_from_uri(GFile *uri);
-gchar *filename_utf8_from_uri(GFile *uri);
+gchar *mime_with_extension(const gchar *mimetype, const gchar *filename);
 
 GList *urilist_to_stringlist(GList *urilist);
 void free_urilist(GList *urilist);
@@ -58,21 +56,18 @@ void free_urilist(GList *urilist);
 #else
 GFile *gtk_file_chooser_get_file(GtkFileChooser *chooser);
 #endif
-/*#define user_bfdir(file) g_strconcat(g_get_home_dir(), "/."PACKAGE"/", file, NULL)*/
-GFile *user_bfdir(const gchar *filename);
 
-gchar *filename_utf8_from_full_path_utf8(const gchar *full_path_utf8);
-
-gchar *get_filename_on_disk_encoding(const gchar *utf8filename);
-gchar *get_utf8filename_from_on_disk_encoding(const gchar *encodedname);
 gboolean string_is_color(const gchar *color);
+
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
 gchar *filemode_to_string(mode_t statmode);
-gchar *return_root_with_protocol(const gchar *url);
+/*gchar *return_root_with_protocol(const gchar *url);*/
 void pointer_switch_addresses(gpointer *a, gpointer *b);
 void list_switch_order(GList *first, GList *second);
 gboolean file_copy(gchar *source, gchar *dest);
-gint find_common_prefixlen_in_stringlist(GList *stringlist);
-gboolean append_string_to_file(gchar *filename, gchar *string);
+/*gint find_common_prefixlen_in_stringlist(GList *stringlist);*/
 /*guint countchars(const gchar *string, const gchar *chars);*/
 gint table_convert_char2int(Tconvert_table *table, const gchar *my_char, Ttcc2i_mode mode);
 gchar *table_convert_int2char(Tconvert_table *table, gint my_int);
@@ -92,17 +87,17 @@ guint utf8_byteoffset_to_charsoffset_cached(const gchar *string, glong byteoffse
 
 gchar *strip_any_whitespace(gchar *string);
 gchar *trunc_on_char(gchar * string, gchar which_char);
-gchar *strip_common_path(char *to_filename, char *from_filename);
+GFile *uri_from_external_input(const gchar *filename, GFile *reldiruri);
 gchar *most_efficient_filename(gchar *filename);
-gchar *create_relative_link_to(gchar * current_filepath, gchar * link_to_filepath);
+gchar *create_relative_link_to(const gchar * current_filepath, const gchar * link_to_filepath);
 
 gchar *strip_trailing_slash(gchar *input);
 gchar *ending_slash(const gchar *dirname);
-gchar *path_get_dirname_with_ending_slash(const gchar *filename);
-gboolean full_path_exists(const gchar *full_path);
+/*gchar *path_get_dirname_with_ending_slash(const gchar *filename);*/
+/*gboolean full_path_exists(const gchar *full_path);*/
 /*gboolean file_exists_and_readable(const gchar * filename);*/
 GFile *return_first_existing_filename(const gchar * filename, ...);
-gboolean filename_test_extensions(gchar **extensions, const gchar *filename);
+/*gboolean filename_test_extensions(gchar **extensions, const gchar *filename);*/
 gchar *bf_str_repeat(const gchar * str, gint number_of);
 gint get_int_from_string(const gchar *string);
 gchar *unique_path(const gchar *basedir, const gchar *prefix, GHashTable *excludehash);
@@ -119,5 +114,39 @@ guint arr3_hash(gconstpointer v);
 gchar *gfile_display_name(GFile *uri,GFileInfo *finfo);
 gboolean gfile_uri_is_parent(GFile *parent, GFile *child, gboolean recursive);
 gchar *get_hostname_from_uri(GFile *uri);
+GList *scan_dir_for_files(const gchar * dir, const gchar *patspec);
+typedef struct {
+	void (*func)();
+	gpointer data;
+} Tcallback;
+void callback_register(GSList **slist, void (*func)(), gpointer data);
+void callback_remove_by_data(GSList **slist, gpointer data);
+void callback_remove_all(GSList **slist);
+
+#define BF_ELIST_HEAD gpointer next, prev
+typedef struct {
+	BF_ELIST_HEAD;
+} Telist;
+#define BF_ELIST(var) ((Telist *)var)
+#define bf_elist_next(var) (var)->next
+#define bf_elist_prev(var) (var)->prev
+
+Telist * bf_elist_prepend(gpointer cur, gpointer new);
+Telist * bf_elist_append(gpointer cur, gpointer new);
+Telist * bf_elist_first(gpointer cur);
+Telist * bf_elist_last(gpointer cur);
+Telist * bf_elist_remove(gpointer toremove);
+
+void print_character_escaped(gunichar uc);
+gint bf_lib_int_to_string(guint value, const gchar **outstr);
+
+gchar *gdk_color_to_rgbstring(GdkColor * color);
+gchar *gdk_color_to_hexstring(GdkColor * color);
+gchar *gdk_color_to_hslstring(GdkColor * color);
+
+gboolean hsl_to_rgb(guint8 hue, guint8 sat, guint8 lum, guint8 *red, guint8 *green, guint8 *blue);
+gboolean parse_colorstring_8bit(const gchar *colorstring, guint8 *red, guint8 *green, guint8 *blue);
+GdkPixbuf *pixbuf_new_for_color(const gchar *colorstring, guint8 *red, guint8 *green, guint8 *blue);
 
 #endif /* __BF_LIB_H_ */
+
